#
# spec file for package leocad
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           leocad
Version:        23.03
Release:        1.7
Summary:        CAD program for creating virtual LEGO models
License:        GPL-2.0-only
URL:            https://www.leocad.org/
Source0:        https://github.com/leozide/leocad/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-devel >= 5.4.0
BuildRequires:  make
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
Requires:       povray

%description
CAD program for creating virtual LEGO models.
It has an intuitive interface, designed to allow
new users to start creating new models without
having to spend too much time learning the
application.

%prep
%setup -q

%build
%qmake5
%make_build

%install
%suse_update_desktop_file -r -G 'CAD Application' %{name} Graphics 3DGraphics
make install INSTALL_ROOT=%{buildroot} DISABLE_UPDATE_CHECK=1 LDRAW_LIBRARY_PATH=%{_datadir}/ldraw
# We install it later correctly
rm -rf %{buildroot}%{_datadir}/doc
# Remove duplicates
%fdupes %{buildroot}%{_datadir}

%files
%license docs/COPYING.txt
%doc docs/{README.txt,CREDITS.txt}
%{_bindir}/leocad
%{_datadir}/applications/leocad.desktop
%{_mandir}/man1/leocad.1%{?ext_man}
%{_datadir}/metainfo/leocad.appdata.xml
%{_datadir}/mime/packages/leocad.xml
%{_datadir}/icons/hicolor/*/apps/leocad.*
%{_datadir}/icons/hicolor/*/mimetypes/application-vnd.leocad.*

%changelog
* Tue Jun 27 2023 Dirk Müller <dmueller@suse.com>
- update to 23.03:
  * Added new timeline menu option to move selection to a new
    step.
  * Place new pieces relative to the side of the piece under the
    mouse.
  * Scan submodels when dragging a new piece into the model.
  * Added support for trackpad pan gesture.
  * Slow down mouse wheel zoom when the shift key is down.
  * Added option to print from the instructions dialog.
  * Weight vertex normals based on the angle of each face.
  * Customizable object colors.
  * Removed commas from descriptions in csv files.
  * Added --export-csv command line option.
  * Almost unlimited control points in synthesized pieces
  * Fixed menus in fullscreen mode on Windows.
  * Fixed missing steps at the end of instructions.
  * Fixed submodels not being added to instructions.
  * Fixed gradient background tiles.
  * Fixed POV render issues with synth parts.
  * Don't show invalid submodels in properties parts list.
* Tue Jul 12 2022 Dirk Müller <dmueller@suse.com>
- update to 21.06:
  * Synthesize Technic Pneumatic Tubes
  * Added option to choose the axis icon location.
  * Added LeoCAD to the Linux Snap Store.
  * Added preview indicator for synth parts.
  * Fixed crash loading certain parts.
  * Fixed moving pieces while editing submodels in place.
  * Fixed loading primitives from ldrawunf.zip.
  * Made library installation optional in the Windows installer.
  * Highlight missing parts in the timeline.
  * Add Unhide selected menu item
- drop patches that are upstream:
  0001-Don-t-enable-relative-transforms-by-default.patch
  0002-Disabled-relative-movement-when-moving-pieces-withou.patch
  0003-Fixed-moving-pieces-while-editing-submodels-in-place.patch
  0004-Fixed-drawing-the-rotate-overlay-during-in-place-sub.patch
* Wed Apr 28 2021 Gustavo Pichorim Boiko <gboiko@suse.com>
- Backport upstream fixes for moving of rotated pieces.
  Added patches:
  * 0001-Don-t-enable-relative-transforms-by-default.patch
  * 0002-Disabled-relative-movement-when-moving-pieces-withou.patch
  * 0003-Fixed-moving-pieces-while-editing-submodels-in-place.patch
  * 0004-Fixed-drawing-the-rotate-overlay-during-in-place-sub.patch
* Sat Apr 17 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 21.03:
  * Added option to draw conditional lines.
  * Added option to draw logos on studs.
  * Added option to draw high contrast studs.
  * Added option to configure edge colors.
  * Added new find/replace widget.
  * Improved Bricklink xml export.
  * Added option to paste parts and keep their original steps.
  * Added model measurements to the Properties Dialog.
  * Load official parts before unofficial parts.
  * Fixed mac retina display issues.
* Wed Jan 13 2021 andy great <andythe_great@pm.me>
- Update to version 21.01.
  * Switched to a dark color theme by default.
  * Added a new interactive 3D preview window.
  * Added an option to fade previous steps and support a new
    translucent fade mode.
  * Added user defined part palettes and favorites.
  * Added stud logo option.
  * Added support for customizing the interface colors.
  * Save files with OMR style headers.
  * Replaced HTML parts list with BOM style image.
  * Use part color instead of the edge color in wireframe mode.
  * Added Spanish and Czech translations.
  * Added language option.
  * Added minifig template import/export options.
  * Added color picker tool.
  * Added support for more synth parts.
  * Added new ways to change the color of pieces.
  * Added option to change the color of the grid origin lines.
  * Added shortcut support to more actions.
  * Added option to disable restoring tabs when loading a model.
  * Added more camera command line options.
  * Added warning when assigning a keyboard shortcut that is
    already assigned to something else.
  * Better part placement when dragging new parts to a model.
  * Improved zoom extents in some cases.
  * Prevent users from collapsing the category/parts lists
    completely.
  * Split console output into stdout and stderr when running in
    CLI mode.
  * Use antialised lines when antialiasing is enabled.
  * Render Dialog fixes and improvements.
  * Fixed errors loading certain MPD files.
  * Fixed view size on retina displays.
  * Fixed view rolling when using Look At.
  * Fixed color popup being shown across multiple monitors.
  * Fixed the context menu showing when a clickable tool is
    assigned to the right mouse button.
* Tue May  5 2020 andy great <andythe_great@pm.me>
- Remove group tag.
* Sun May  3 2020 andy great <andythe_great@pm.me>
- Initial package release.
